<?php

namespace Drupal\stubby\Routing;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\Route;

/**
 * Class StubRoutes.
 *
 * @package Drupal\stubby\Routing
 */
class StubRoutes implements ContainerInjectionInterface {

  /**
   * The entity manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * StubRoutes constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityManager = $entity_type_manager;
  }

  /**
   * Creates dynamic routes based on stubs.
   */
  public function routes() {
    $routes = [];
    $stubs = $this->entityManager->getStorage('stub')->loadMultiple();
    foreach ($stubs as $stub) {

      $methods = [];
      foreach ($stub->getMethods() as $key => $enabled) {
        if ($enabled) {
          $methods[] = $key;
        }
      }

      $routes[$stub->id()] = new Route(
        $stub->getPath(),
        [
          '_controller' => '\Drupal\stubby\Controller\Output::response',
          'stub' => $stub->id(),
        ],
        ['_access' => 'TRUE'],
        [],
        '',
        [],
        $methods
      );
    }

    return $routes;
  }

}
